function y= desat_b(u);

% *************************************************************
% Cette fonction reoit en entre la variable u  7 composantes
% en colonne:
%      u(1) roulis phi
%      u(2) tangage teta
%      u(3) lacet psi
%      u(4) vitesse roulis
%      u(5) vitesse tangage
%      u(6) vitesse lacet
%      u(7) Moment cintique H de la roue, moment qui diverge

% En sortie y est un couple de dsaturation(vecteur colonne 
% de dimension3, cr par 2 bobines:
%     Une sur l'axe lacet travaillant autour du passage quateur
%     L'autre sur l'axe roulis, travaillant au passage des ples
% Le basculement s'opre quand l'un des couples devient suprieur
%  l'autre

% Le temps 0 de la simulation est suppos pris lors d'un passage 
% quateur au noeud ascendant.

% *************************************************************

global coeff rotation_orbitale gain_desat_magn moment_magnetique

global H0 coeff_desature Hmax Hmin couple_desat

% *********** CALCUL DU COUPLE DES MAGNETOCOUPLEURS  **********

% Temps de la simulation

tps=u(8);w0=rotation_orbitale;

% Champ magnetique en axes XYZ (repre orbital)

BX=coeff*cos(w0*tps);
BY=0;
BZ=-2*coeff*sin(w0*tps);

% ************** CHAMP MAGNETIQUE EN AXES SATELLITE  ***********

% Matrice de passage du repre orbital au repre satellite dans
% le cadre des petits angles:

Pmat=[1 u(3) -u(2);-u(3) 1 u(1);u(2) -u(1) 1];

B=Pmat*[BX;BY;BZ];  % changement d'axes (en colonne)

% *************    COUPLE GENERE    *****************
% moment_magnetique est le module du moment magntique de chaque
% magntocoupleur

Mtz=moment_magnetique*[0;0;1]; % bobine sur z:
Mtx=moment_magnetique*[1;0;0]; % bobine sur x:

% Calcul de chaque couple:

couple1=gain_desat_magn.*cross(Mtx,B);couple2=gain_desat_magn.*cross(Mtz,B);

% Test de basculement d'une bobine sur l'autre

if norm(couple1)>=norm(couple2),
    couple_desature=norm(couple1);
  else
    couple_desature=norm(couple2);  
end

% Utilisation simultane des 2 bobines
% couple_desature=norm(couple1)+norm(couple2);

% ********  TESTS DE DECLENCHEMENT DE DESATURATION   **************

y=[0;0;0]; % Initialisation du couple de dsaturation, nul en gnral


if H0<0 & u(7)<=Hmax,
  coeff_desature=1;
  
end

if H0<0 & u(7)>=Hmin,
  coeff_desature=-1;
end

if coeff_desature==1 & abs(H0+0.01-u(7))>0.01,
  y=[0;-couple_desature;0]; % couple1,couple2,
end

if coeff_desature==-1 & abs(H0-0.01-u(7))>0.01,
  y=[0;couple_desature;0];
end

if abs(H0+0.01-u(7))<=0.011 | abs(H0-0.01-u(7))<=0.011
  y=[0;0;0];
  coeff_desature=0;

end

end 

%   **********************   FIN DE LA FONCTION   *****************


