function [ret,x0,str,ts,xts]=mom_sim(t,x,u,flag);
%MOM_SIM	is the M-file description of the SIMULINK system named MOM_SIM.
%	The block-diagram can be displayed by typing: MOM_SIM.
%
%	SYS=MOM_SIM(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes MOM_SIM to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling MOM_SIM with a FLAG of zero:
%	[SIZES]=MOM_SIM([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[0,38,1008,700])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '30000')
set_param(sys,'Min step size', '15')
set_param(sys,'Max step size', '12')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/MATLAB Fcn',[sys,'/','delta4'])
set_param([sys,'/','delta4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','-[(It-Il)*u(1) (Ir-Il)*u(2) 0]*3*rotation_orbitale^2',...
		'Output Width','3',...
		'Mask Display','GRADIENT')
set_param([sys,'/','delta4'],...
		'position',[100,199,225,241])

add_block('built-in/Gain',[sys,'/','Gain1'])
set_param([sys,'/','Gain1'],...
		'hide name',0,...
		'Gain','0',...
		'position',[250,207,275,233])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'hide name',0,...
		'Value','[8e-5;8e-5;0]',...
		'Mask Display','Couple constant',...
		'position',[105,134,220,176])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'hide name',0,...
		'position',[245,142,270,168])


%     Subsystem  'Extras2'.

new_system([sys,'/','Extras2'])
set_param([sys,'/','Extras2'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras2'],...
		'Mask Display','PRENDRE UN PAS DE 0.1 s\nPOUR AVOIR LA PRECISION')


%     Finished composite block 'Extras2'.

set_param([sys,'/','Extras2'],...
		'ForeGround',2,...
		'BackGround',7,...
		'hide name',0,...
		'position',[520,245,795,286])


%     Subsystem  'XY Graph'.

new_system([sys,'/','XY Graph'])
set_param([sys,'/','XY Graph'],'Location',[8,52,282,245])

add_block('built-in/Inport',[sys,'/','XY Graph/y'])
set_param([sys,'/','XY Graph/y'],...
		'Port','2',...
		'position',[10,100,30,120])

add_block('built-in/Inport',[sys,'/','XY Graph/x'])
set_param([sys,'/','XY Graph/x'],...
		'position',[10,30,30,50])

add_block('built-in/Mux',[sys,'/','XY Graph/Mux'])
set_param([sys,'/','XY Graph/Mux'],...
		'inputs','2',...
		'position',[100,61,130,94])

add_block('built-in/S-Function',[sys,'/',['XY Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['XY Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunxy',...
		'parameters','ax, st',...
		'position',[185,70,235,90])
add_line([sys,'/','XY Graph'],[35,110;70,110;70,85;95,85])
add_line([sys,'/','XY Graph'],[35,40;70,40;70,70;95,70])
add_line([sys,'/','XY Graph'],[135,80;180,80])
set_param([sys,'/','XY Graph'],...
		'Mask Display','plot(0,0,100,100,[12,91,91,12,12],[90,90,45,45,90],[51,57,65,75,80,79,75,67,60,54,51,48,42,34,28,27,31,42,51],[71,68,66,66,72,79,83,84,81,77,71,60,54,54,58,65,71,74,71])')
set_param([sys,'/','XY Graph'],...
		'Mask Type','XY scope.',...
		'Mask Dialogue','XY scope using MATLAB graph window.\nFirst input is used as time base.\nEnter plotting ranges.|x-min:|x-max:|y-min:|y-max:')
set_param([sys,'/','XY Graph'],...
		'Mask Translate','ax = [@1, @2, @3, @4];st=-1;',...
		'Mask Help','This block can be used to explore limit cycles. Look at the m-file sfunxy.m to see how it works.',...
		'Mask Entries','-3\/+3\/-3\/3\/')


%     Finished composite block 'XY Graph'.

set_param([sys,'/','XY Graph'],...
		'position',[775,344,830,411])

add_block('built-in/To Workspace',[sys,'/','To Workspace7'])
set_param([sys,'/','To Workspace7'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','2000',...
		'position',[650,316,730,334])

add_block('built-in/Scope',[sys,'/','Scope4'])
set_param([sys,'/','Scope4'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Vgain','10.000000',...
		'Hgain','10000.000000',...
		'Vmax','20.000000',...
		'Hmax','20000.000000',...
		'Window',[62,134,442,484])
set_param([sys,'/','Scope4'],...
		'position',[705,400,735,430])

add_block('built-in/Scope',[sys,'/','Scope3'])
set_param([sys,'/','Scope3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Vgain','5.000000',...
		'Hgain','11000.000000',...
		'Vmax','10.000000',...
		'Hmax','22000.000000',...
		'Window',[587,131,967,535])
set_param([sys,'/','Scope3'],...
		'position',[705,345,735,375])

add_block('built-in/To Workspace',[sys,'/','To Workspace8'])
set_param([sys,'/','To Workspace8'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','2000',...
		'position',[660,436,740,454])

add_block('built-in/Scope',[sys,'/','Scope6'])
set_param([sys,'/','Scope6'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Vgain','50.000000',...
		'Hgain','10000.000000',...
		'Vmax','100.000000',...
		'Hmax','20000.000000',...
		'Window',[562,335,942,685])
set_param([sys,'/','Scope6'],...
		'position',[750,500,780,530])

add_block('built-in/To Workspace',[sys,'/','To Workspace10'])
set_param([sys,'/','To Workspace10'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','moment',...
		'buffer','2000',...
		'position',[650,526,730,544])

add_block('built-in/To Workspace',[sys,'/','To Workspace9'])
set_param([sys,'/','To Workspace9'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','2000',...
		'position',[660,471,740,489])

add_block('built-in/MATLAB Fcn',[sys,'/','delta1'])
set_param([sys,'/','delta1'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','u(3)*180/pi',...
		'Output Width','1',...
		'Mask Display','LACET',...
		'position',[570,398,635,432])

add_block('built-in/MATLAB Fcn',[sys,'/','delta2'])
set_param([sys,'/','delta2'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','u(2)*180/pi',...
		'Output Width','1',...
		'Mask Display','TANGAGE',...
		'position',[560,441,630,479])

add_block('built-in/MATLAB Fcn',[sys,'/','delta3'])
set_param([sys,'/','delta3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','u(7)',...
		'Output Width','1',...
		'Mask Display','MOMENT',...
		'position',[570,498,630,532])

add_block('built-in/Scope',[sys,'/','Scope5'])
set_param([sys,'/','Scope5'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Vgain','0.500000',...
		'Hgain','11280.000000',...
		'Vmax','1.000000',...
		'Hmax','22560.000000',...
		'Window',[505,48,885,398])
set_param([sys,'/','Scope5'],...
		'position',[750,445,780,475])

add_block('built-in/MATLAB Fcn',[sys,'/','delta'])
set_param([sys,'/','delta'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','u(1)*180/pi',...
		'Output Width','1',...
		'Mask Display','ROULIS',...
		'position',[570,343,630,377])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'Initial','etat_init',...
		'position',[470,369,500,431])

add_block('built-in/Gain',[sys,'/','Gain4'])
set_param([sys,'/','Gain4'],...
		'hide name',0,...
		'position',[245,402,270,428])


%     Subsystem  'Subsystem2'.

new_system([sys,'/','Subsystem2'])
set_param([sys,'/','Subsystem2'],'Location',[54,410,839,599])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem2/delta6'])
set_param([sys,'/','Subsystem2/delta6'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','coup_tuy(u)',...
		'Output Width','3',...
		'position',[255,73,315,107])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem2/delta5'])
set_param([sys,'/','Subsystem2/delta5'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','Cpl_tuy(u)',...
		'Output Width','5',...
		'position',[175,73,235,107])

add_block('built-in/Mux',[sys,'/','Subsystem2/Mux'])
set_param([sys,'/','Subsystem2/Mux'],...
		'hide name',0,...
		'inputs','[7 1]',...
		'position',[115,31,155,144])

add_block('built-in/Clock',[sys,'/','Subsystem2/Clock1'])
set_param([sys,'/','Subsystem2/Clock1'],...
		'hide name',0,...
		'position',[40,99,75,131])

add_block('built-in/Inport',[sys,'/','Subsystem2/in_1'])
set_param([sys,'/','Subsystem2/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','Subsystem2/out_1'])
set_param([sys,'/','Subsystem2/out_1'],...
		'position',[345,80,365,100])

add_block('built-in/Integrator',[sys,'/','Subsystem2/Integrator'])
set_param([sys,'/','Subsystem2/Integrator'],...
		'hide name',0,...
		'Initial','etat_init',...
		'position',[490,224,520,286])

add_block('built-in/Integrator',[sys,'/','Subsystem2/Integrator1'])
set_param([sys,'/','Subsystem2/Integrator1'],...
		'hide name',0,...
		'position',[410,14,440,76])

add_block('built-in/Scope',[sys,'/','Subsystem2/Scope3'])
set_param([sys,'/','Subsystem2/Scope3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Vgain','5.000000',...
		'Hgain','11000.000000',...
		'Vmax','10.000000',...
		'Hmax','22000.000000',...
		'Window',[587,131,967,535])
set_param([sys,'/','Subsystem2/Scope3'],...
		'position',[725,200,755,230])

add_block('built-in/Scope',[sys,'/','Subsystem2/Scope4'])
set_param([sys,'/','Subsystem2/Scope4'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Vgain','5.000000',...
		'Hgain','11000.000000',...
		'Vmax','10.000000',...
		'Hmax','22000.000000',...
		'Window',[587,131,967,535])
set_param([sys,'/','Subsystem2/Scope4'],...
		'position',[500,30,530,60])

add_block('built-in/To Workspace',[sys,'/','Subsystem2/To Workspace10'])
set_param([sys,'/','Subsystem2/To Workspace10'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','moment_tuyere',...
		'buffer','2000',...
		'position',[510,91,590,109])
add_line([sys,'/','Subsystem2'],[160,90;170,90])
add_line([sys,'/','Subsystem2'],[240,90;250,90])
add_line([sys,'/','Subsystem2'],[80,115;110,115])
add_line([sys,'/','Subsystem2'],[40,60;110,60])
add_line([sys,'/','Subsystem2'],[320,90;340,90])
add_line([sys,'/','Subsystem2'],[320,90;320,45;405,45])
add_line([sys,'/','Subsystem2'],[445,45;495,45])
add_line([sys,'/','Subsystem2'],[465,45;465,100;505,100])
set_param([sys,'/','Subsystem2'],...
		'Mask Display','CONTROLE\nPAR TUYERES')


%     Finished composite block 'Subsystem2'.

set_param([sys,'/','Subsystem2'],...
		'BackGround',6,...
		'hide name',0,...
		'position',[90,329,225,371])

add_block('built-in/Gain',[sys,'/','Gain3'])
set_param([sys,'/','Gain3'],...
		'hide name',0,...
		'Gain','0',...
		'position',[245,337,270,363])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'inputs','+++++',...
		'position',[295,121,325,449])

add_block('built-in/MATLAB Fcn',[sys,'/','delta6'])
set_param([sys,'/','delta6'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','[0;-u(2);0]*rappel_integral',...
		'Output Width','3',...
		'Mask Display','PID',...
		'position',[100,533,165,567])

add_block('built-in/Integrator',[sys,'/','Integrator1'])
set_param([sys,'/','Integrator1'],...
		'hide name',0,...
		'position',[190,526,215,574])

add_block('built-in/State-Space',[sys,'/',['Matrix',13,'Gain1']])
set_param([sys,'/',['Matrix',13,'Gain1']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Matrix',13,'Gain1']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','[0 0 0;0 0 0;0 0 0;1/Ir 0 0;0 1/It 0;0 0 1/Il;0 1 0]\/')
set_param([sys,'/',['Matrix',13,'Gain1']],...
		'position',[275,536,300,564])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'inputs','+++',...
		'position',[405,175,425,625])

add_block('built-in/MATLAB Fcn',[sys,'/','derivsys'])
set_param([sys,'/','derivsys'],...
		'hide name',0,...
		'MATLAB Fcn','derivsys(u)',...
		'Output Width','7',...
		'Mask Display','SATELLITE LIBRE',...
		'Mask Help','Dynamique du satellite, libre de tout couple')
set_param([sys,'/','derivsys'],...
		'position',[100,456,240,504])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION SIMULATION\npar double clic souris\nLACEMENT DE MOM_DAT.M',...
		'Mask Dialogue','eval(''mom_dat'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',7,...
		'BackGround',5,...
		'hide name',0,...
		'position',[525,120,795,186])

add_block('built-in/Gain',[sys,'/','Gain2'])
set_param([sys,'/','Gain2'],...
		'hide name',0,...
		'position',[245,272,270,298])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[50,424,317,632])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux'])
set_param([sys,'/','Subsystem/Mux'],...
		'inputs','3',...
		'position',[130,48,165,152])

add_block('built-in/Outport',[sys,'/','Subsystem/out_1'])
set_param([sys,'/','Subsystem/out_1'],...
		'position',[195,90,215,110])

add_block('built-in/Sine Wave',[sys,'/','Subsystem/Sine Wave'])
set_param([sys,'/','Subsystem/Sine Wave'],...
		'amplitude','8e-5',...
		'frequency','rotation_orbitale',...
		'phase','pi',...
		'position',[35,55,55,75])

add_block('built-in/Constant',[sys,'/','Subsystem/Constant2'])
set_param([sys,'/','Subsystem/Constant2'],...
		'Value','0',...
		'position',[35,90,55,110])

add_block('built-in/Sine Wave',[sys,'/','Subsystem/Sine Wave1'])
set_param([sys,'/','Subsystem/Sine Wave1'],...
		'amplitude','8e-5',...
		'frequency','rotation_orbitale',...
		'phase','pi/2',...
		'position',[30,125,50,145])

add_block('built-in/State-Space',[sys,'/',['Subsystem/Matrix',13,'Gain2']])
set_param([sys,'/',['Subsystem/Matrix',13,'Gain2']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Subsystem/Matrix',13,'Gain2']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','1\/',...
		'position',[80,51,105,79])

add_block('built-in/State-Space',[sys,'/',['Subsystem/Matrix',13,'Gain1']])
set_param([sys,'/',['Subsystem/Matrix',13,'Gain1']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Subsystem/Matrix',13,'Gain1']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','1\/',...
		'position',[75,121,100,149])
add_line([sys,'/','Subsystem'],[60,100;125,100])
add_line([sys,'/','Subsystem'],[170,100;190,100])
add_line([sys,'/','Subsystem'],[60,65;75,65])
add_line([sys,'/','Subsystem'],[110,65;125,65])
add_line([sys,'/','Subsystem'],[55,135;70,135])
add_line([sys,'/','Subsystem'],[105,135;125,135])
set_param([sys,'/','Subsystem'],...
		'Mask Display','COUPLE INERTIEL\nCONSTANT')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'position',[95,259,220,311])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'hide name',0,...
		'position',[605,195,625,215])

add_block('built-in/To Workspace',[sys,'/','To Workspace11'])
set_param([sys,'/','To Workspace11'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','2000',...
		'position',[655,196,735,214])

add_block('built-in/State-Space',[sys,'/',['Matrix',13,'Gain']])
set_param([sys,'/',['Matrix',13,'Gain']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','[0 0 0;0 0 0;0 0 0;1/Ir 0 0;0 1/It 0;0 0 1/Il;0 0 0]\/')
set_param([sys,'/',['Matrix',13,'Gain']],...
		'position',[350,236,375,264])


%     Subsystem  'Subsystem3'.

new_system([sys,'/','Subsystem3'])
set_param([sys,'/','Subsystem3'],'Location',[505,382,980,577])
open_system([sys,'/','Subsystem3'])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem3/delta8'])
set_param([sys,'/','Subsystem3/delta8'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'MATLAB Fcn','desature(u)',...
		'Output Width','3',...
		'Mask Display','DESATURATION\nPAR TUYERE',...
		'position',[205,57,325,93])

add_block('built-in/Gain',[sys,'/','Subsystem3/Gain5'])
set_param([sys,'/','Subsystem3/Gain5'],...
		'hide name',0,...
		'Gain','0',...
		'position',[345,62,370,88])

add_block('built-in/Gain',[sys,'/','Subsystem3/Gain6'])
set_param([sys,'/','Subsystem3/Gain6'],...
		'hide name',0,...
		'position',[350,117,375,143])

add_block('built-in/Sum',[sys,'/','Subsystem3/Sum2'])
set_param([sys,'/','Subsystem3/Sum2'],...
		'position',[400,47,415,158])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem3/delta9'])
set_param([sys,'/','Subsystem3/delta9'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'MATLAB Fcn','desat_b(u)',...
		'Output Width','3',...
		'Mask Display','DESATURATION\nMAGNETOCOUPLEURS')
set_param([sys,'/','Subsystem3/delta9'],...
		'position',[195,111,335,149])

add_block('built-in/Clock',[sys,'/','Subsystem3/Clock1'])
set_param([sys,'/','Subsystem3/Clock1'],...
		'hide name',0,...
		'position',[55,127,90,163])

add_block('built-in/Mux',[sys,'/','Subsystem3/Mux'])
set_param([sys,'/','Subsystem3/Mux'],...
		'inputs','[7 1]',...
		'position',[130,100,170,160])

add_block('built-in/Outport',[sys,'/','Subsystem3/out_1'])
set_param([sys,'/','Subsystem3/out_1'],...
		'position',[445,95,465,115])

add_block('built-in/Inport',[sys,'/','Subsystem3/in_1'])
set_param([sys,'/','Subsystem3/in_1'],...
		'position',[30,65,50,85])
add_line([sys,'/','Subsystem3'],[55,75;200,75])
add_line([sys,'/','Subsystem3'],[180,75;85,75;85,115;125,115])
add_line([sys,'/','Subsystem3'],[380,130;395,130])
add_line([sys,'/','Subsystem3'],[375,75;395,75])
add_line([sys,'/','Subsystem3'],[340,130;345,130])
add_line([sys,'/','Subsystem3'],[330,75;340,75])
add_line([sys,'/','Subsystem3'],[175,130;190,130])
add_line([sys,'/','Subsystem3'],[95,145;125,145])
add_line([sys,'/','Subsystem3'],[420,105;440,105])
set_param([sys,'/','Subsystem3'],...
		'Mask Display','DESATURATION\nTUYERES OU\nMAGNETOCOUPLEURS')


%     Finished composite block 'Subsystem3'.

set_param([sys,'/','Subsystem3'],...
		'BackGround',7,...
		'hide name',0,...
		'position',[75,389,225,441])

add_block('built-in/To Workspace',[sys,'/','To Workspace12'])
set_param([sys,'/','To Workspace12'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','desat',...
		'buffer','2000',...
		'position',[290,501,370,519])

add_block('built-in/Scope',[sys,'/','Scope7'])
set_param([sys,'/','Scope7'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Vgain','0.000100',...
		'Hgain','10000.000000',...
		'Vmax','0.000200',...
		'Hmax','20000.000000',...
		'Window',[85,316,465,666])
set_param([sys,'/','Scope7'],...
		'position',[300,570,330,600])

add_block('built-in/Note',[sys,'/',['SCAO: STABILISATION PAR MOMENT EMBARQUE.CONTRLE PAR TUYERES SUR SEUIL.',13,' PILOTAGE DE LA ROUE P.D ou P.I.D',13,'CONTRLE DE SATURATION ',13,'DESATURATION PAR TUYERES OU PAR MAGNETOCOUPLEURS']])
set_param([sys,'/',['SCAO: STABILISATION PAR MOMENT EMBARQUE.CONTRLE PAR TUYERES SUR SEUIL.',13,' PILOTAGE DE LA ROUE P.D ou P.I.D',13,'CONTRLE DE SATURATION ',13,'DESATURATION PAR TUYERES OU PAR MAGNETOCOUPLEURS']],...
		'ForeGround',2)
set_param([sys,'/',['SCAO: STABILISATION PAR MOMENT EMBARQUE.CONTRLE PAR TUYERES SUR SEUIL.',13,' PILOTAGE DE LA ROUE P.D ou P.I.D',13,'CONTRLE DE SATURATION ',13,'DESATURATION PAR TUYERES OU PAR MAGNETOCOUPLEURS']],...
		'Font Name','Arial')
set_param([sys,'/',['SCAO: STABILISATION PAR MOMENT EMBARQUE.CONTRLE PAR TUYERES SUR SEUIL.',13,' PILOTAGE DE LA ROUE P.D ou P.I.D',13,'CONTRLE DE SATURATION ',13,'DESATURATION PAR TUYERES OU PAR MAGNETOCOUPLEURS']],...
		'Font Weight','bold')
set_param([sys,'/',['SCAO: STABILISATION PAR MOMENT EMBARQUE.CONTRLE PAR TUYERES SUR SEUIL.',13,' PILOTAGE DE LA ROUE P.D ou P.I.D',13,'CONTRLE DE SATURATION ',13,'DESATURATION PAR TUYERES OU PAR MAGNETOCOUPLEURS']],...
		'Font Size',16)
set_param([sys,'/',['SCAO: STABILISATION PAR MOMENT EMBARQUE.CONTRLE PAR TUYERES SUR SEUIL.',13,' PILOTAGE DE LA ROUE P.D ou P.I.D',13,'CONTRLE DE SATURATION ',13,'DESATURATION PAR TUYERES OU PAR MAGNETOCOUPLEURS']],...
		'position',[485,-5,490,0])

add_block('built-in/Note',[sys,'/','Robert Guiziou  novembre 2001'])
set_param([sys,'/','Robert Guiziou  novembre 2001'],...
		'position',[720,615,725,620])
add_line(sys,[330,285;345,250])
add_line(sys,[380,250;400,250])
add_line(sys,[635,360;700,360])
add_line(sys,[635,360;645,325])
add_line(sys,[640,415;700,415])
add_line(sys,[640,415;640,445;655,445])
add_line(sys,[635,460;745,460])
add_line(sys,[635,460;635,480;655,480])
add_line(sys,[635,515;745,515])
add_line(sys,[635,515;645,535])
add_line(sys,[505,400;540,400;540,515;565,515])
add_line(sys,[540,460;555,460])
add_line(sys,[630,205;650,205])
add_line(sys,[540,415;565,415])
add_line(sys,[505,400;510,400;510,630;45,630;45,220;95,220])
add_line(sys,[675,415;675,385;750,385;750,360;770,360])
add_line(sys,[665,360;665,395;770,395])
add_line(sys,[430,400;465,400])
add_line(sys,[540,400;540,360;565,360])
add_line(sys,[225,155;240,155])
add_line(sys,[275,155;290,155])
add_line(sys,[230,220;245,220])
add_line(sys,[280,220;290,220])
add_line(sys,[225,285;240,285])
add_line(sys,[275,285;290,285])
add_line(sys,[230,350;240,350])
add_line(sys,[275,350;290,350])
add_line(sys,[245,480;345,480;345,400;400,400])
add_line(sys,[275,415;290,415])
add_line(sys,[170,550;185,550])
add_line(sys,[220,550;270,550])
add_line(sys,[305,550;400,550])
add_line(sys,[45,220;45,480;95,480])
add_line(sys,[45,220;45,415;70,415])
add_line(sys,[45,220;45,550;95,550])
add_line(sys,[275,415;285,510])
add_line(sys,[230,415;240,415])
add_line(sys,[275,495;250,495;250,585;295,585])
add_line(sys,[45,350;85,350])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
