function [ret,x0,str,ts,xts]=stab_sim(t,x,u,flag);
%STAB_SIM	is the M-file description of the SIMULINK system named STAB_SIM.
%	The block-diagram can be displayed by typing: STAB_SIM.
%
%	SYS=STAB_SIM(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes STAB_SIM to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling STAB_SIM with a FLAG of zero:
%	[SIZES]=STAB_SIM([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[100,63,636,448])
     open_system(sys)
end;
set_param(sys,'BackGround',0)
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '50')
set_param(sys,'Min step size', '0.1')
set_param(sys,'Max step size', '0.1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/',['STABILISATION D''UN SATELLITE PAR SPIN']])
set_param([sys,'/',['STABILISATION D''UN SATELLITE PAR SPIN']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[257,5,262,10])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Value','[0 0 0]''',...
		'position',[5,106,65,134])


%     Subsystem  'UnNamed'.

new_system([sys,'/','UnNamed'])
set_param([sys,'/','UnNamed'],'Location',[518,183,1004,488])

add_block('built-in/Sum',[sys,'/','UnNamed/Sum'])
set_param([sys,'/','UnNamed/Sum'],...
		'position',[260,44,275,131])

add_block('built-in/Mux',[sys,'/','UnNamed/Mux'])
set_param([sys,'/','UnNamed/Mux'],...
		'orientation',2,...
		'inputs','[7 3]',...
		'position',[180,134,210,276])

add_block('built-in/Outport',[sys,'/','UnNamed/out_1'])
set_param([sys,'/','UnNamed/out_1'],...
		'position',[415,80,435,100])

add_block('built-in/Inport',[sys,'/','UnNamed/in_1'])
set_param([sys,'/','UnNamed/in_1'],...
		'position',[25,55,45,75])

add_block('built-in/State-Space',[sys,'/','UnNamed/Matrix gain.'])
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','[1/Ir 0 0;0 1/It 0;0 0 1/Il;0 0 0;1 0 0;0 0 0;0 0 0 ]\/')
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'position',[100,48,155,82])

add_block('built-in/Integrator',[sys,'/','UnNamed/integration'])
set_param([sys,'/','UnNamed/integration'],...
		'Initial','etat_init',...
		'position',[310,75,345,105])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed/stab_sys.m'])
set_param([sys,'/','UnNamed/stab_sys.m'],...
		'orientation',2,...
		'MATLAB Fcn','stab_sys(u)',...
		'Output Width','7',...
		'position',[65,189,135,221])

add_block('built-in/Constant',[sys,'/','UnNamed/Constant'])
set_param([sys,'/','UnNamed/Constant'],...
		'orientation',2,...
		'Value','[Ir It Il]',...
		'position',[240,227,320,253])
add_line([sys,'/','UnNamed'],[160,65;255,65])
add_line([sys,'/','UnNamed'],[60,205;25,205;25,110;255,110])
add_line([sys,'/','UnNamed'],[175,205;140,205])
add_line([sys,'/','UnNamed'],[235,240;215,240])
add_line([sys,'/','UnNamed'],[350,90;410,90])
add_line([sys,'/','UnNamed'],[360,90;360,170;215,170])
add_line([sys,'/','UnNamed'],[280,90;305,90])
add_line([sys,'/','UnNamed'],[50,65;95,65])
set_param([sys,'/','UnNamed'],...
		'Mask Display','INTEGRATION')


%     Finished composite block 'UnNamed'.

set_param([sys,'/','UnNamed'],...
		'ForeGround',1,...
		'BackGround',6,...
		'hide name',0,...
		'position',[95,84,225,156])

add_block('built-in/Note',[sys,'/','Contrle de nutation avec couple gnr par tuyres'])
set_param([sys,'/','Contrle de nutation avec couple gnr par tuyres'],...
		'ForeGround',5,...
		'position',[245,35,250,40])

add_block('built-in/To Workspace',[sys,'/','To Workspace7'])
set_param([sys,'/','To Workspace7'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','delta',...
		'buffer','500',...
		'position',[365,151,445,169])

add_block('built-in/MATLAB Fcn',[sys,'/','delta'])
set_param([sys,'/','delta'],...
		'BackGround',3,...
		'MATLAB Fcn','acos(2*(u(4)^2+u(7)^2)/norm(u(4:7))^2-1)*180/pi',...
		'Output Width','1',...
		'position',[275,128,335,162])

add_block('built-in/MATLAB Fcn',[sys,'/','mom_abs.m'])
set_param([sys,'/','mom_abs.m'],...
		'BackGround',3,...
		'MATLAB Fcn','mom_abs(u)',...
		'Output Width','3',...
		'position',[275,188,335,222])

add_block('built-in/To Workspace',[sys,'/','To Workspace8'])
set_param([sys,'/','To Workspace8'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','moment_absolu',...
		'position',[365,212,475,238])

add_block('built-in/To Workspace',[sys,'/','To Workspace9'])
set_param([sys,'/','To Workspace9'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','nutation',...
		'buffer','500',...
		'position',[370,275,460,295])

add_block('built-in/MATLAB Fcn',[sys,'/','nutation'])
set_param([sys,'/','nutation'],...
		'BackGround',3,...
		'MATLAB Fcn','180/pi*nutation(u)',...
		'Output Width','1',...
		'position',[275,253,335,287])

add_block('built-in/To Workspace',[sys,'/','To Workspace11'])
set_param([sys,'/','To Workspace11'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','moment_controle',...
		'buffer','500',...
		'position',[380,344,485,366])

add_block('built-in/MATLAB Fcn',[sys,'/','moment de controle'])
set_param([sys,'/','moment de controle'],...
		'BackGround',3,...
		'MATLAB Fcn','mom_cont(u)',...
		'Output Width','1',...
		'position',[280,318,340,352])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'BackGround',5,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','500',...
		'position',[65,223,140,247])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'BackGround',5,...
		'hide name',0,...
		'position',[10,222,40,248])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\npar double clic souris',...
		'Mask Dialogue','eval(''stab_dat'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',2,...
		'BackGround',5,...
		'hide name',0,...
		'position',[10,275,150,320])

add_block('built-in/Note',[sys,'/','Sign:GUIZIOU septembre 2001'])
set_param([sys,'/','Sign:GUIZIOU septembre 2001'],...
		'position',[100,335,105,340])

add_block('built-in/Scope',[sys,'/','Scope6'])
set_param([sys,'/','Scope6'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','10.000000',...
		'Hgain','50.000000',...
		'Vmax','20.000000',...
		'Hmax','100.000000',...
		'Window',[631,30,1011,380],...
		'position',[490,320,520,350])

add_block('built-in/Scope',[sys,'/','Scope5'])
set_param([sys,'/','Scope5'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','0.200000',...
		'Hgain','50.000000',...
		'Vmax','0.400000',...
		'Hmax','100.000000',...
		'Window',[631,30,1011,380])
open_system([sys,'/','Scope5'])
set_param([sys,'/','Scope5'],...
		'position',[485,255,515,285])

add_block('built-in/Scope',[sys,'/','Scope3'])
set_param([sys,'/','Scope3'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','2.000000',...
		'Hgain','50.000000',...
		'Vmax','4.000000',...
		'Hmax','100.000000',...
		'Window',[631,30,1011,380])
open_system([sys,'/','Scope3'])
set_param([sys,'/','Scope3'],...
		'position',[480,130,510,160])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','solution',...
		'buffer','500',...
		'position',[400,83,500,107])

add_block('built-in/Scope',[sys,'/','Scope4'])
set_param([sys,'/','Scope4'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','1000.000000',...
		'Hgain','50.000000',...
		'Vmax','2000.000000',...
		'Hmax','100.000000',...
		'Window',[631,30,1011,380])
open_system([sys,'/','Scope4'])
set_param([sys,'/','Scope4'],...
		'position',[485,190,515,220])
add_line(sys,[70,120;90,120])
add_line(sys,[45,235;60,235])
add_line(sys,[230,120;250,120;250,95;395,95])
add_line(sys,[250,120;250,145;270,145])
add_line(sys,[250,145;250,205;270,205])
add_line(sys,[250,205;250,270;270,270])
add_line(sys,[345,335;485,335])
add_line(sys,[345,335;365,335;375,355])
add_line(sys,[250,270;250,335;275,335])
add_line(sys,[340,270;480,270])
add_line(sys,[340,270;355,270;365,285])
add_line(sys,[340,205;480,205])
add_line(sys,[340,205;350,205;360,225])
add_line(sys,[340,145;475,145])
add_line(sys,[340,145;340,160;360,160])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
