function [ret,x0,str,ts,xts]=derivsim(t,x,u,flag);
%DERIVSIM	is the M-file description of the SIMULINK system named DERIVSIM.
%	The block-diagram can be displayed by typing: DERIVSIM.
%
%	SYS=DERIVSIM(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes DERIVSIM to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling DERIVSIM with a FLAG of zero:
%	[SIZES]=DERIVSIM([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[34,78,634,490])
     open_system(sys)
end;
set_param(sys,'BackGround',0)
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '50000')
set_param(sys,'Min step size', '50')
set_param(sys,'Max step size', '50')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Scope',[sys,'/','Scope2'])
set_param([sys,'/','Scope2'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','10.000000',...
		'Hgain','50000.000000',...
		'Vmax','20.000000',...
		'Hmax','100000.000000',...
		'Window',[650,370,980,754])
open_system([sys,'/','Scope2'])
set_param([sys,'/','Scope2'],...
		'position',[465,210,495,240])

add_block('built-in/Scope',[sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','20.000000',...
		'Hgain','50000.000000',...
		'Vmax','40.000000',...
		'Hmax','100000.000000',...
		'Window',[29,351,392,715])
open_system([sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'position',[465,170,495,200])

add_block('built-in/To Workspace',[sys,'/','To Workspace6'])
set_param([sys,'/','To Workspace6'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','2500',...
		'position',[395,237,445,253])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn2'])
set_param([sys,'/','MATLAB Fcn2'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','roulis(u)',...
		'Output Width','1',...
		'position',[300,228,360,262])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','2500',...
		'position',[395,197,445,213])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','2500',...
		'position',[395,152,445,168])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn'])
set_param([sys,'/','MATLAB Fcn'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','-180/pi*asin(2*(u(5)*u(7)-u(4)*u(6)))',...
		'Output Width','1',...
		'position',[300,143,360,177])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn1'])
set_param([sys,'/','MATLAB Fcn1'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','lacet(u)',...
		'Output Width','1',...
		'position',[300,188,360,222])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Value','[0 0 0]''',...
		'position',[35,146,95,174])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','90.000000',...
		'Hgain','50000.000000',...
		'Vmax','180.000000',...
		'Hmax','100000.000000',...
		'Window',[641,18,1021,443])
open_system([sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'position',[465,125,495,155])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','solution',...
		'buffer','2500',...
		'position',[310,277,360,293])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn3'])
set_param([sys,'/','MATLAB Fcn3'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','energie(u)',...
		'Output Width','1',...
		'position',[305,323,365,357])

add_block('built-in/To Workspace',[sys,'/','To Workspace7'])
set_param([sys,'/','To Workspace7'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie',...
		'buffer','2500',...
		'position',[390,330,460,350])

add_block('built-in/Scope',[sys,'/','Scope3'])
set_param([sys,'/','Scope3'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','0.000200',...
		'Hgain','50000.000000',...
		'Vmax','0.000400',...
		'Hmax','100000.000000',...
		'Window',[305,337,635,651])
open_system([sys,'/','Scope3'])
set_param([sys,'/','Scope3'],...
		'position',[475,305,505,335])


%     Subsystem  'UnNamed'.

new_system([sys,'/','UnNamed'])
set_param([sys,'/','UnNamed'],'Location',[133,155,619,506])

add_block('built-in/Sum',[sys,'/','UnNamed/Sum'])
set_param([sys,'/','UnNamed/Sum'],...
		'position',[260,44,275,131])

add_block('built-in/Outport',[sys,'/','UnNamed/out_1'])
set_param([sys,'/','UnNamed/out_1'],...
		'position',[415,80,435,100])

add_block('built-in/Inport',[sys,'/','UnNamed/in_1'])
set_param([sys,'/','UnNamed/in_1'],...
		'position',[25,55,45,75])

add_block('built-in/State-Space',[sys,'/','UnNamed/Matrix gain.'])
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','[1/Ir 0 0;0 1/It 0;0 0 1/Il;0 0 0;1 0 0;0 0 0;0 0 0 ]\/')
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'position',[100,48,155,82])

add_block('built-in/Integrator',[sys,'/','UnNamed/Integrator'])
set_param([sys,'/','UnNamed/Integrator'],...
		'Initial','etat_init',...
		'position',[310,75,345,105])

add_block('built-in/Mux',[sys,'/','UnNamed/Mux'])
set_param([sys,'/','UnNamed/Mux'],...
		'orientation',2,...
		'inputs','[7 3 1 1]',...
		'position',[145,119,175,321])

add_block('built-in/Constant',[sys,'/','UnNamed/Constant'])
set_param([sys,'/','UnNamed/Constant'],...
		'orientation',2,...
		'Value','[Ir It Il]',...
		'position',[235,182,315,208])

add_block('built-in/Constant',[sys,'/','UnNamed/Constant1'])
set_param([sys,'/','UnNamed/Constant1'],...
		'orientation',2,...
		'Value','rotation_orbitale',...
		'position',[235,233,345,257])

add_block('built-in/Clock',[sys,'/','UnNamed/Clock'])
set_param([sys,'/','UnNamed/Clock'],...
		'BackGround',5,...
		'hide name',0,...
		'position',[250,285,270,305])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed/magneto.m'])
set_param([sys,'/','UnNamed/magneto.m'],...
		'orientation',2,...
		'MATLAB Fcn','deriv_b(u)',...
		'Output Width','7',...
		'position',[50,204,120,236])
add_line([sys,'/','UnNamed'],[160,65;255,65])
add_line([sys,'/','UnNamed'],[45,220;25,220;25,110;255,110])
add_line([sys,'/','UnNamed'],[140,220;125,220])
add_line([sys,'/','UnNamed'],[230,245;180,245])
add_line([sys,'/','UnNamed'],[230,195;180,195])
add_line([sys,'/','UnNamed'],[350,90;410,90])
add_line([sys,'/','UnNamed'],[360,90;360,145;180,145])
add_line([sys,'/','UnNamed'],[280,90;305,90])
add_line([sys,'/','UnNamed'],[50,65;95,65])
add_line([sys,'/','UnNamed'],[275,295;180,295])
set_param([sys,'/','UnNamed'],...
		'Mask Display','INTEGRATION')


%     Finished composite block 'UnNamed'.

set_param([sys,'/','UnNamed'],...
		'ForeGround',1,...
		'BackGround',6,...
		'hide name',0,...
		'position',[110,124,240,196])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\npar double clic souris',...
		'Mask Dialogue','eval(''derivdat'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',2,...
		'BackGround',5,...
		'hide name',0,...
		'position',[80,275,220,320])

add_block('built-in/Note',[sys,'/','GUIZIOU novembre 2001'])
set_param([sys,'/','GUIZIOU novembre 2001'],...
		'position',[150,355,155,360])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'BackGround',5,...
		'hide name',0,...
		'position',[85,230,105,250])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'BackGround',5,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','2500',...
		'position',[170,232,220,248])

add_block('built-in/Note',[sys,'/',['QUATERNIONS:ETUDE DU TANGAGE,ROULIS',13,'ET LACET',13,' Gradient de gravit et petits angles']])
set_param([sys,'/',['QUATERNIONS:ETUDE DU TANGAGE,ROULIS',13,'ET LACET',13,' Gradient de gravit et petits angles']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[292,5,297,10])

add_block('built-in/Note',[sys,'/','Stabilisation par la drive du champ magntique terrestre'])
set_param([sys,'/','Stabilisation par la drive du champ magntique terrestre'],...
		'ForeGround',5,...
		'Font Size',16,...
		'position',[295,80,300,85])
add_line(sys,[100,160;105,160])
add_line(sys,[110,240;165,240])
add_line(sys,[245,160;295,160])
add_line(sys,[365,160;390,160])
add_line(sys,[280,160;280,285;305,285])
add_line(sys,[280,205;295,205])
add_line(sys,[365,205;390,205])
add_line(sys,[375,205;375,185;460,185])
add_line(sys,[365,245;390,245])
add_line(sys,[375,245;375,225;460,225])
add_line(sys,[280,245;295,245])
add_line(sys,[375,160;375,140;460,140])
add_line(sys,[280,285;280,340;300,340])
add_line(sys,[370,340;385,340])
add_line(sys,[370,340;370,320;470,320])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
