function y=magneto(u);

global coeff Kg Kr Kt Kl
% ************************************************
% Le vecteur d'entre pour le traitement du systme
% diffrentielu est  12 composantes.
%
%	u(1)=p    rotation absolue satellite sur x
%	u(2)=q    ...........................sur y
%	u(3)=r    ...........................sur z
%
%	u(4)=q0   Premire composante du quaternion
%	u(5)=q1   Deuxime ........................
%	u(6)=q2   Troisime .......................
%	u(7)=q3   Quatrime .......................
% *************************************************

% Les donnes inertielles seront fournies plus loin
%	u(8)=Ir   Inertie roulis
%       u(9)=It   ....... tangage
%	u(10)=Il  ....... lacet
%       u(12)=temps
%
% ainsi que la vitesse angulaire orbitale w0
% 	u(11)=w0
% Dans le bloc diagramme nous multiplexerons ces entres
%       7+3+1=11
%
% ******************************************************

% Composantes de la rotation
p=u(1);q=u(2);r=u(3);

% normalisation du quaternion d'entre
v=u(4:7)/norm(u(4:7));

% Composantes du quaternion
q0=v(1);q1=v(2);q2=v(3);q3=v(4);

% Donnes inertielles et constantes orbitales
Ir=u(8);It=u(9);Il=u(10);

% Donnes particulires
w0=u(11);k=6*w0^2;

% Matrice de  passage  l'aide du quaternion v

Pmat=passage(v);

% Temps de la simulation

tps=u(12);

% Champ magnetique en axes XYZ (repre orbital)

BX=coeff*cos(w0*tps);
BY=0;
BZ=-2*coeff*sin(w0*tps);

% CHAMP MAGNETIQUE EN AXES SATELLITE

B=inv(Pmat)*[BX BY BZ]';
Bx=B(1);By=B(2);Bz=B(3);

% ************* Couple magnto-coupleurs **************

matB=[-Bx^2 0 Bx*Bz;0 -Bx^2-Bz^2 0;Bx*Bz By*Bz -Bx^2]/norm(B);

% Moment magntique command

% Rotation relative

rot=[p-w0*Pmat(2,1);q-w0*Pmat(2,2);r-w0*Pmat(2,3)];

moment=[Kr*rot(1);Kt*rot(2);Kl*rot(3)];

couple_magn=matB*moment;

couple_magn=couple_magn;
% +10*matB*[20*Pmat(3,2);-Pmat(3,1);50*Pmat(2,1)];
% couple_magn=[0;0;0];

y=[];

% Calcul des drives de p q r avec le gradient de gravit seul

y(1)=(Il-It)/Ir*(-q*r+k*(q2*q3+q0*q1)*(2*q0^2+2*q3^2-1))+couple_magn(1)/Ir;
y(2)=(Ir-Il)/It*(-p*r+k*(q1*q3-q0*q2)*(2*q0^2+2*q3^2-1))+couple_magn(2)/It;
y(3)=(It-Ir)/Il*(-q*p+2*k*(q2*q3+q0*q1)*(q1*q3-q0*q2))+couple_magn(3)/Il;


% Calcul des drives du quaternion, avec les calculs intermdiaires

 p21=2*(q1*q2+q0*q3);
 p22=2*(q0^2+q2^2)-1;
 p23=2*(q2*q3-q0*q1);

% Matrice W* de rotation relative en tant que quaternion

Matrice_rotation=[0 -p+w0*p21 -q+w0*p22 -r+w0*p23
                 p-w0*p21 0 r-w0*p23 -q+w0*p22
		 q-w0*p22 -r+w0*p23 0 p-w0*p21
		 r-w0*p23 q-w0*p22 -p+w0*p21 0];

z=0.5*Matrice_rotation*[q0 q1 q2 q3]';

y=[y z']';

end
