function [ret,x0,str,ts,xts]=stab_sim(t,x,u,flag);
%STAB_SIM	is the M-file description of the SIMULINK system named STAB_SIM.
%	The block-diagram can be displayed by typing: STAB_SIM.
%
%	SYS=STAB_SIM(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes STAB_SIM to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling STAB_SIM with a FLAG of zero:
%	[SIZES]=STAB_SIM([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[77,63,666,528])
     open_system(sys)
end;
set_param(sys,'BackGround',0)
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '10000')
set_param(sys,'Min step size', '1')
set_param(sys,'Max step size', '5')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/',['STABILISATION D''UN SATELLITE PAR SPIN']])
set_param([sys,'/',['STABILISATION D''UN SATELLITE PAR SPIN']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[287,5,292,10])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'BackGround',5,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','2000',...
		'position',[180,192,230,208])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'BackGround',5,...
		'hide name',0,...
		'position',[125,190,145,210])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Value','[0 0 0]''',...
		'position',[35,106,95,134])


%     Subsystem  'Extras2'.

new_system([sys,'/','Extras2'])
set_param([sys,'/','Extras2'],'Location',[4,42,1012,704])
set_param([sys,'/','Extras2'],...
		'Mask Display','VISUALISATION\npar double clic souris',...
		'Mask Dialogue','eval(''psot_vis'')')


%     Finished composite block 'Extras2'.

set_param([sys,'/','Extras2'],...
		'ForeGround',2,...
		'BackGround',5,...
		'hide name',0,...
		'position',[15,235,155,280])


%     Subsystem  'UnNamed'.

new_system([sys,'/','UnNamed'])
set_param([sys,'/','UnNamed'],'Location',[518,183,1004,488])

add_block('built-in/Sum',[sys,'/','UnNamed/Sum'])
set_param([sys,'/','UnNamed/Sum'],...
		'position',[260,44,275,131])

add_block('built-in/Mux',[sys,'/','UnNamed/Mux'])
set_param([sys,'/','UnNamed/Mux'],...
		'orientation',2,...
		'inputs','[7 3]',...
		'position',[180,134,210,276])

add_block('built-in/Outport',[sys,'/','UnNamed/out_1'])
set_param([sys,'/','UnNamed/out_1'],...
		'position',[415,80,435,100])

add_block('built-in/Inport',[sys,'/','UnNamed/in_1'])
set_param([sys,'/','UnNamed/in_1'],...
		'position',[25,55,45,75])

add_block('built-in/State-Space',[sys,'/','UnNamed/Matrix gain.'])
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','[1/Ir 0 0;0 1/It 0;0 0 1/Il;0 0 0;1 0 0;0 0 0;0 0 0 ]\/')
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'position',[100,48,155,82])

add_block('built-in/Integrator',[sys,'/','UnNamed/integration'])
set_param([sys,'/','UnNamed/integration'],...
		'Initial','etat_init',...
		'position',[310,75,345,105])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed/stab_sys.m'])
set_param([sys,'/','UnNamed/stab_sys.m'],...
		'orientation',2,...
		'MATLAB Fcn','stab_sys(u)',...
		'Output Width','7',...
		'position',[65,189,135,221])

add_block('built-in/Constant',[sys,'/','UnNamed/Constant'])
set_param([sys,'/','UnNamed/Constant'],...
		'orientation',2,...
		'Value','[Ir It Il]',...
		'position',[240,227,320,253])
add_line([sys,'/','UnNamed'],[160,65;255,65])
add_line([sys,'/','UnNamed'],[60,205;25,205;25,110;255,110])
add_line([sys,'/','UnNamed'],[175,205;140,205])
add_line([sys,'/','UnNamed'],[235,240;215,240])
add_line([sys,'/','UnNamed'],[350,90;410,90])
add_line([sys,'/','UnNamed'],[360,90;360,170;215,170])
add_line([sys,'/','UnNamed'],[280,90;305,90])
add_line([sys,'/','UnNamed'],[50,65;95,65])
set_param([sys,'/','UnNamed'],...
		'Mask Display','INTEGRATION')


%     Finished composite block 'UnNamed'.

set_param([sys,'/','UnNamed'],...
		'ForeGround',1,...
		'BackGround',6,...
		'hide name',0,...
		'position',[125,84,255,156])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','solution',...
		'buffer','500',...
		'position',[370,83,470,107])

add_block('built-in/MATLAB Fcn',[sys,'/','nutation'])
set_param([sys,'/','nutation'],...
		'BackGround',3,...
		'MATLAB Fcn','180/pi*nutation(u)',...
		'Output Width','1',...
		'position',[305,288,365,322])

add_block('built-in/To Workspace',[sys,'/','To Workspace9'])
set_param([sys,'/','To Workspace9'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','nutation',...
		'buffer','2000',...
		'position',[420,330,510,350])

add_block('built-in/Scope',[sys,'/','Scope5'])
set_param([sys,'/','Scope5'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','0.001000',...
		'Hgain','2000.000000',...
		'Vmax','0.002000',...
		'Hmax','4000.000000',...
		'Window',[631,30,1011,380])
open_system([sys,'/','Scope5'])
set_param([sys,'/','Scope5'],...
		'position',[455,290,485,320])

add_block('built-in/MATLAB Fcn',[sys,'/','mom_abs.m'])
set_param([sys,'/','mom_abs.m'],...
		'BackGround',3,...
		'MATLAB Fcn','mom_abs(u)',...
		'Output Width','3',...
		'position',[305,208,365,242])

add_block('built-in/To Workspace',[sys,'/','To Workspace8'])
set_param([sys,'/','To Workspace8'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','moment_absolu',...
		'position',[400,252,510,278])

add_block('built-in/MATLAB Fcn',[sys,'/','delta'])
set_param([sys,'/','delta'],...
		'BackGround',3,...
		'MATLAB Fcn','acos(2*(u(4)^2+u(7)^2)/norm(u(4:7))^2-1)*180/pi',...
		'Output Width','1',...
		'position',[305,138,365,172])

add_block('built-in/To Workspace',[sys,'/','To Workspace7'])
set_param([sys,'/','To Workspace7'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','delta',...
		'buffer','2000',...
		'position',[405,181,485,199])

add_block('built-in/Note',[sys,'/','Couple gnr par tuyres'])
set_param([sys,'/','Couple gnr par tuyres'],...
		'ForeGround',5,...
		'position',[275,35,280,40])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\npar double clic souris',...
		'Mask Dialogue','eval(''stab_dat'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',2,...
		'BackGround',5,...
		'hide name',0,...
		'position',[15,295,155,340])

add_block('built-in/Note',[sys,'/','Sign:GUIZIOU septembre 2001'])
set_param([sys,'/','Sign:GUIZIOU septembre 2001'],...
		'position',[105,350,110,355])

add_block('built-in/Scope',[sys,'/','Scope3'])
set_param([sys,'/','Scope3'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','2.000000',...
		'Hgain','2000.000000',...
		'Vmax','4.000000',...
		'Hmax','4000.000000',...
		'Window',[633,122,1013,472])
open_system([sys,'/','Scope3'])
set_param([sys,'/','Scope3'],...
		'position',[455,140,485,170])

add_block('built-in/Scope',[sys,'/','Scope4'])
set_param([sys,'/','Scope4'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','1000.000000',...
		'Hgain','500.000000',...
		'Vmax','2000.000000',...
		'Hmax','1000.000000',...
		'Window',[631,30,1011,380])
open_system([sys,'/','Scope4'])
set_param([sys,'/','Scope4'],...
		'position',[455,210,485,240])
add_line(sys,[100,120;120,120])
add_line(sys,[150,200;175,200])
add_line(sys,[260,120;280,120;280,95;365,95])
add_line(sys,[280,120;280,155;300,155])
add_line(sys,[280,155;280,225;300,225])
add_line(sys,[280,225;280,305;300,305])
add_line(sys,[370,305;450,305])
add_line(sys,[370,305;405,305;415,340])
add_line(sys,[370,225;450,225])
add_line(sys,[370,225;385,225;395,265])
add_line(sys,[370,155;450,155])
add_line(sys,[370,155;370,190;400,190])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
