function [ret,x0,str,ts,xts]=psot_sim(t,x,u,flag);
%PSOT_SIM	is the M-file description of the SIMULINK system named PSOT_SIM.
%	The block-diagram can be displayed by typing: PSOT_SIM.
%
%	SYS=PSOT_SIM(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes PSOT_SIM to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling PSOT_SIM with a FLAG of zero:
%	[SIZES]=PSOT_SIM([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[6,43,712,538])
     open_system(sys)
end;
set_param(sys,'BackGround',0)
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '50')
set_param(sys,'Min step size', '0.1')
set_param(sys,'Max step size', '0.1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/','en'])
set_param([sys,'/','en'],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[287,5,292,10])

add_block('built-in/Note',[sys,'/','Mouvement de Poinsot'])
set_param([sys,'/','Mouvement de Poinsot'],...
		'ForeGround',5,...
		'position',[275,55,280,60])

add_block('built-in/To Workspace',[sys,'/','To Workspace6'])
set_param([sys,'/','To Workspace6'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','500',...
		'position',[395,197,445,213])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn2'])
set_param([sys,'/','MATLAB Fcn2'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','roulis(u)',...
		'Output Width','1',...
		'position',[300,188,360,222])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','500',...
		'position',[395,157,445,173])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','500',...
		'position',[395,112,445,128])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn'])
set_param([sys,'/','MATLAB Fcn'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','-180/pi*asin(2*(u(5)*u(7)-u(4)*u(6)))',...
		'Output Width','1',...
		'position',[300,103,360,137])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn1'])
set_param([sys,'/','MATLAB Fcn1'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','lacet(u)',...
		'Output Width','1',...
		'position',[300,148,360,182])


%     Subsystem  'UnNamed'.

new_system([sys,'/','UnNamed'])
set_param([sys,'/','UnNamed'],'Location',[518,183,1004,488])

add_block('built-in/Sum',[sys,'/','UnNamed/Sum'])
set_param([sys,'/','UnNamed/Sum'],...
		'position',[260,44,275,131])

add_block('built-in/Mux',[sys,'/','UnNamed/Mux'])
set_param([sys,'/','UnNamed/Mux'],...
		'orientation',2,...
		'inputs','[7 3]',...
		'position',[180,134,210,276])

add_block('built-in/Outport',[sys,'/','UnNamed/out_1'])
set_param([sys,'/','UnNamed/out_1'],...
		'position',[415,80,435,100])

add_block('built-in/Inport',[sys,'/','UnNamed/in_1'])
set_param([sys,'/','UnNamed/in_1'],...
		'position',[25,55,45,75])

add_block('built-in/State-Space',[sys,'/','UnNamed/Matrix gain.'])
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','[1/Ir 0 0;0 1/It 0;0 0 1/Il;0 0 0;1 0 0;0 0 0;0 0 0 ]\/')
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'position',[100,48,155,82])

add_block('built-in/Integrator',[sys,'/','UnNamed/integration'])
set_param([sys,'/','UnNamed/integration'],...
		'Initial','etat_init',...
		'position',[310,75,345,105])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed/psot_sys.m'])
set_param([sys,'/','UnNamed/psot_sys.m'],...
		'orientation',2,...
		'MATLAB Fcn','psot_sys(u)',...
		'Output Width','7',...
		'position',[65,189,135,221])

add_block('built-in/Constant',[sys,'/','UnNamed/Constant'])
set_param([sys,'/','UnNamed/Constant'],...
		'orientation',2,...
		'Value','[Ir It Il]',...
		'position',[240,227,320,253])
add_line([sys,'/','UnNamed'],[160,65;255,65])
add_line([sys,'/','UnNamed'],[60,205;25,205;25,110;255,110])
add_line([sys,'/','UnNamed'],[175,205;140,205])
add_line([sys,'/','UnNamed'],[235,240;215,240])
add_line([sys,'/','UnNamed'],[350,90;410,90])
add_line([sys,'/','UnNamed'],[360,90;360,170;215,170])
add_line([sys,'/','UnNamed'],[280,90;305,90])
add_line([sys,'/','UnNamed'],[50,65;95,65])
set_param([sys,'/','UnNamed'],...
		'Mask Display','INTEGRATION')


%     Finished composite block 'UnNamed'.

set_param([sys,'/','UnNamed'],...
		'ForeGround',1,...
		'BackGround',6,...
		'hide name',0,...
		'position',[135,84,265,156])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Value','[0 0 0]''',...
		'position',[35,106,95,134])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn3'])
set_param([sys,'/','MATLAB Fcn3'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','energie(u)',...
		'Output Width','1',...
		'position',[305,263,365,297])

add_block('built-in/To Workspace',[sys,'/','To Workspace7'])
set_param([sys,'/','To Workspace7'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie',...
		'position',[415,286,495,304])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','100.000000',...
		'Hgain','2500.000000',...
		'Vmax','200.000000',...
		'Hmax','5000.000000',...
		'Window',[631,30,1011,380],...
		'position',[515,85,545,115])

add_block('built-in/Scope',[sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','20.000000',...
		'Hgain','20000.000000',...
		'Vmax','40.000000',...
		'Hmax','40000.000000',...
		'Window',[497,404,860,768])
open_system([sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'position',[515,130,545,160])

add_block('built-in/Scope',[sys,'/','Scope2'])
set_param([sys,'/','Scope2'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','5.000000',...
		'Hgain','20000.000000',...
		'Vmax','10.000000',...
		'Hmax','40000.000000',...
		'Window',[387,414,717,737],...
		'position',[515,170,545,200])

add_block('built-in/Scope',[sys,'/','Scope3'])
set_param([sys,'/','Scope3'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','1000.000000',...
		'Hgain','2500.000000',...
		'Vmax','2000.000000',...
		'Hmax','5000.000000',...
		'Window',[631,30,1011,380])
set_param([sys,'/','Scope3'],...
		'position',[520,265,550,295])

add_block('built-in/Scope',[sys,'/','Scope5'])
set_param([sys,'/','Scope5'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','2.000000',...
		'Hgain','600.000000',...
		'Vmax','4.000000',...
		'Hmax','1200.000000',...
		'Window',[631,30,1011,380],...
		'position',[530,375,560,405])

add_block('built-in/Scope',[sys,'/','Scope4'])
set_param([sys,'/','Scope4'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','1000.000000',...
		'Hgain','500.000000',...
		'Vmax','2000.000000',...
		'Hmax','1000.000000',...
		'Window',[631,30,1011,380])
set_param([sys,'/','Scope4'],...
		'position',[525,315,555,345])

add_block('built-in/To Workspace',[sys,'/','To Workspace8'])
set_param([sys,'/','To Workspace8'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','moment_absolu',...
		'position',[395,337,505,363])

add_block('built-in/To Workspace',[sys,'/','To Workspace9'])
set_param([sys,'/','To Workspace9'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','nutation',...
		'position',[420,400,510,420])

add_block('built-in/MATLAB Fcn',[sys,'/','nutation'])
set_param([sys,'/','nutation'],...
		'BackGround',3,...
		'MATLAB Fcn','nutat(u)',...
		'Output Width','1',...
		'position',[310,373,370,407])

add_block('built-in/MATLAB Fcn',[sys,'/','mom_abs.m'])
set_param([sys,'/','mom_abs.m'],...
		'BackGround',3,...
		'MATLAB Fcn','mom_abs(u)',...
		'Output Width','3',...
		'position',[305,313,365,347])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','solution',...
		'buffer','500',...
		'position',[380,230,475,260])


%     Subsystem  'Extras2'.

new_system([sys,'/','Extras2'])
set_param([sys,'/','Extras2'],'Location',[4,42,1012,704])
set_param([sys,'/','Extras2'],...
		'Mask Display','VISUALISATION\npar double clic souris',...
		'Mask Dialogue','eval(''psot_vis'')')


%     Finished composite block 'Extras2'.

set_param([sys,'/','Extras2'],...
		'ForeGround',2,...
		'BackGround',5,...
		'hide name',0,...
		'position',[385,440,525,485])

add_block('built-in/Note',[sys,'/','Sign:GUIZIOU septembre 2001'])
set_param([sys,'/','Sign:GUIZIOU septembre 2001'],...
		'position',[120,455,125,460])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'BackGround',5,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','500',...
		'position',[130,202,180,218])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'BackGround',5,...
		'hide name',0,...
		'position',[75,200,95,220])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\npar double clic souris',...
		'Mask Dialogue','eval(''psot_dat'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',2,...
		'BackGround',5,...
		'hide name',0,...
		'position',[60,245,200,290])
add_line(sys,[100,120;130,120])
add_line(sys,[100,210;125,210])
add_line(sys,[270,120;295,120])
add_line(sys,[365,120;390,120])
add_line(sys,[280,120;280,245;375,245])
add_line(sys,[280,165;295,165])
add_line(sys,[365,165;390,165])
add_line(sys,[375,165;375,145;510,145])
add_line(sys,[365,205;390,205])
add_line(sys,[375,205;375,185;510,185])
add_line(sys,[280,205;295,205])
add_line(sys,[375,120;375,100;510,100])
add_line(sys,[280,245;280,280;300,280])
add_line(sys,[370,280;515,280])
add_line(sys,[370,280;370,295;410,295])
add_line(sys,[370,330;520,330])
add_line(sys,[370,330;380,330;390,350])
add_line(sys,[280,280;280,330;300,330])
add_line(sys,[375,390;525,390])
add_line(sys,[375,390;405,390;415,410])
add_line(sys,[280,330;280,390;305,390])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
