function [ret,x0,str,ts,xts]=stab_sim(t,x,u,flag);
%STAB_SIM	is the M-file description of the SIMULINK system named STAB_SIM.
%	The block-diagram can be displayed by typing: STAB_SIM.
%
%	SYS=STAB_SIM(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes STAB_SIM to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling STAB_SIM with a FLAG of zero:
%	[SIZES]=STAB_SIM([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[6,43,562,416])
     open_system(sys)
end;
set_param(sys,'BackGround',0)
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '500')
set_param(sys,'Min step size', '0.1')
set_param(sys,'Max step size', '0.1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'UnNamed'.

new_system([sys,'/','UnNamed'])
set_param([sys,'/','UnNamed'],'Location',[518,183,1004,488])

add_block('built-in/Sum',[sys,'/','UnNamed/Sum'])
set_param([sys,'/','UnNamed/Sum'],...
		'position',[260,44,275,131])

add_block('built-in/Mux',[sys,'/','UnNamed/Mux'])
set_param([sys,'/','UnNamed/Mux'],...
		'orientation',2,...
		'inputs','[7 3]',...
		'position',[180,134,210,276])

add_block('built-in/Outport',[sys,'/','UnNamed/out_1'])
set_param([sys,'/','UnNamed/out_1'],...
		'position',[415,80,435,100])

add_block('built-in/Inport',[sys,'/','UnNamed/in_1'])
set_param([sys,'/','UnNamed/in_1'],...
		'position',[25,55,45,75])

add_block('built-in/State-Space',[sys,'/','UnNamed/Matrix gain.'])
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','[1/Ir 0 0;0 1/It 0;0 0 1/Il;0 0 0;1 0 0;0 0 0;0 0 0 ]\/')
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'position',[100,48,155,82])

add_block('built-in/Integrator',[sys,'/','UnNamed/integration'])
set_param([sys,'/','UnNamed/integration'],...
		'Initial','etat_init',...
		'position',[310,75,345,105])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed/stab_sys.m'])
set_param([sys,'/','UnNamed/stab_sys.m'],...
		'orientation',2,...
		'MATLAB Fcn','stab_sys(u)',...
		'Output Width','7',...
		'position',[65,189,135,221])

add_block('built-in/Constant',[sys,'/','UnNamed/Constant'])
set_param([sys,'/','UnNamed/Constant'],...
		'orientation',2,...
		'Value','[Ir It Il]',...
		'position',[240,227,320,253])
add_line([sys,'/','UnNamed'],[160,65;255,65])
add_line([sys,'/','UnNamed'],[60,205;25,205;25,110;255,110])
add_line([sys,'/','UnNamed'],[175,205;140,205])
add_line([sys,'/','UnNamed'],[235,240;215,240])
add_line([sys,'/','UnNamed'],[350,90;410,90])
add_line([sys,'/','UnNamed'],[360,90;360,170;215,170])
add_line([sys,'/','UnNamed'],[280,90;305,90])
add_line([sys,'/','UnNamed'],[50,65;95,65])
set_param([sys,'/','UnNamed'],...
		'Mask Display','INTEGRATION')


%     Finished composite block 'UnNamed'.

set_param([sys,'/','UnNamed'],...
		'ForeGround',1,...
		'BackGround',6,...
		'hide name',0,...
		'position',[135,84,265,156])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Value','[0 0 0]''',...
		'position',[35,106,95,134])

add_block('built-in/MATLAB Fcn',[sys,'/','nutation'])
set_param([sys,'/','nutation'],...
		'BackGround',3,...
		'MATLAB Fcn','nutat(u)',...
		'Output Width','1',...
		'position',[310,263,370,297])

add_block('built-in/MATLAB Fcn',[sys,'/','mom_abs.m'])
set_param([sys,'/','mom_abs.m'],...
		'BackGround',3,...
		'MATLAB Fcn','mom_abs(u)',...
		'Output Width','3',...
		'position',[305,203,365,237])

add_block('built-in/Scope',[sys,'/','Scope3'])
set_param([sys,'/','Scope3'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','20.000000',...
		'Hgain','500.000000',...
		'Vmax','40.000000',...
		'Hmax','1000.000000',...
		'Window',[631,30,1011,380])
open_system([sys,'/','Scope3'])
set_param([sys,'/','Scope3'],...
		'position',[510,130,540,160])

add_block('built-in/To Workspace',[sys,'/','To Workspace7'])
set_param([sys,'/','To Workspace7'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','delta',...
		'buffer','500',...
		'position',[415,151,495,169])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn3'])
set_param([sys,'/','MATLAB Fcn3'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','acos(2*(u(4)^2+u(5)^2)/norm(u(4:7))^2-1)*180/pi',...
		'Output Width','1',...
		'position',[305,128,365,162])

add_block('built-in/Note',[sys,'/','STABILISATION SATELLITE PAR SPIN'])
set_param([sys,'/','STABILISATION SATELLITE PAR SPIN'],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[282,5,287,10])

add_block('built-in/Note',[sys,'/','EFFET DES COUPLES CONSTANTS'])
set_param([sys,'/','EFFET DES COUPLES CONSTANTS'],...
		'ForeGround',5,...
		'position',[275,45,280,50])

add_block('built-in/To Workspace',[sys,'/','To Workspace8'])
set_param([sys,'/','To Workspace8'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','moment_absolu',...
		'position',[395,227,505,253])

add_block('built-in/Scope',[sys,'/','Scope4'])
set_param([sys,'/','Scope4'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','1000.000000',...
		'Hgain','500.000000',...
		'Vmax','2000.000000',...
		'Hmax','1000.000000',...
		'Window',[631,30,1011,380])
open_system([sys,'/','Scope4'])
set_param([sys,'/','Scope4'],...
		'position',[515,205,545,235])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','solution',...
		'buffer','500',...
		'position',[365,88,490,112])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'BackGround',5,...
		'hide name',0,...
		'position',[125,248,150,272])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'BackGround',5,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','500',...
		'position',[175,245,245,275])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\npar double clic souris',...
		'Mask Dialogue','eval(''stab_dat'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',2,...
		'BackGround',5,...
		'hide name',0,...
		'position',[115,315,255,360])

add_block('built-in/Note',[sys,'/','Sign:GUIZIOU septembre 2001'])
set_param([sys,'/','Sign:GUIZIOU septembre 2001'],...
		'position',[420,335,425,340])

add_block('built-in/To Workspace',[sys,'/','To Workspace9'])
set_param([sys,'/','To Workspace9'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','nutation',...
		'position',[405,290,495,310])

add_block('built-in/Scope',[sys,'/','Scope5'])
set_param([sys,'/','Scope5'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','2.000000',...
		'Hgain','600.000000',...
		'Vmax','4.000000',...
		'Hmax','1200.000000',...
		'Window',[631,30,1011,380])
open_system([sys,'/','Scope5'])
set_param([sys,'/','Scope5'],...
		'position',[515,265,545,295])
add_line(sys,[100,120;130,120])
add_line(sys,[155,260;170,260])
add_line(sys,[270,120;280,120;280,100;360,100])
add_line(sys,[280,120;280,145;300,145])
add_line(sys,[370,145;505,145])
add_line(sys,[370,145;370,160;410,160])
add_line(sys,[370,220;510,220])
add_line(sys,[370,220;380,220;390,240])
add_line(sys,[280,145;280,220;300,220])
add_line(sys,[375,280;510,280])
add_line(sys,[375,280;390,280;400,300])
add_line(sys,[280,220;280,280;305,280])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
